@@ -9,27 +9,26 @@ with [NetworkManager::send_message] method.
 This example shows two peers sending `ping` and `pong` messages to each other.
 
 ```
-use wasm_peers::ConnectionType;
+use wasm_peers::{ConnectionType, SessionId};
 use wasm_peers::one_to_one::NetworkManager;
 use web_sys::console;
 
 const SIGNALING_SERVER_URL: &str = "ws://0.0.0.0:9001/one-to-one";
+const STUN_SERVER_URL: &str = "stun:openrelay.metered.ca:80";
 
 let session_id = SessionId::new("some-session-id".to_string());
 let mut server = NetworkManager::new(
     SIGNALING_SERVER_URL,
     session_id.clone(),
-    ConnectionType::Stun,
+    ConnectionType::Stun { urls: STUN_SERVER_URL.to_string() },
 )
 .unwrap();
 
 let server_clone = server.clone();
 let server_on_open = move || server_clone.send_message("ping!").unwrap();
 let server_on_message = {
-    let server_received_message = server_received_message.clone();
     move |message| {
         console::log_1(&format!("server received message: {}", message).into());
-        *server_received_message.borrow_mut() = true;
     }
 };
 server.start(server_on_open, server_on_message).unwrap();
@@ -37,17 +36,15 @@ server.start(server_on_open, server_on_message).unwrap();
 let mut client = NetworkManager::new(
     SIGNALING_SERVER_URL,
     session_id,
-    ConnectionType::Stun,
+    ConnectionType::Stun { urls: STUN_SERVER_URL.to_string() },
 )
 .unwrap();
 let client_on_open = || { /* do nothing */ };
 let client_clone = client.clone();
 let client_on_message = {
-    let client_received_message = client_received_message.clone();
     move |message| {
         console::log_1(&format!("client received message: {}", message).into());
         client_clone.send_message("pong!").unwrap();
-        *client_received_message.borrow_mut() = true;
     }
 };
 client.start(client_on_open, client_on_message).unwrap();
@@ -63,10 +60,10 @@ use crate::one_to_one::callbacks::{
 };
 use crate::utils::{create_peer_connection, ConnectionType};
 use log::debug;
-use wasm_peers_protocol::SessionId;
 use std::cell::RefCell;
 use std::rc::Rc;
 use wasm_bindgen::JsValue;
+use wasm_peers_protocol::SessionId;
 use web_sys::RtcPeerConnection;
 use web_sys::{RtcDataChannel, WebSocket};
 
@@ -172,20 +169,30 @@ impl NetworkManager {
         Ok(())
     }
 
+    fn datachannel(&self) -> Result<RtcDataChannel, JsValue> {
+        Ok(self
+            .inner
+            .borrow()
+            .data_channel
+            .as_ref()
+            .ok_or_else(|| JsValue::from_str("no data channel set on instance yet"))?
+            .clone())
+    }
+
     /// Send message to the other end of the connection.
     /// It might fail if the connection is not yet set up
     /// and thus should only be called after `on_open_callback` triggers.
     /// Otherwise it will result in an error.
     pub fn send_message(&self, message: &str) -> Result<(), JsValue> {
         debug!("server will try to send a message: {:?}", &message);
-        self.inner
-            .borrow()
-            .data_channel
-            .as_ref()
-            .ok_or_else(|| JsValue::from_str("no data channel set on instance yet"))?
-            // this is an ugly fix to the fact, that if you send empty string as message
-            // webrtc fails with a cryptic "The operation failed for an operation-specific reason"
-            // message
-            .send_with_str(&format!("x{}", message))
+        // FIXME(tkarwowski): this is an ugly fix to the fact, that if you send empty string as message
+        //  webrtc fails with a cryptic "The operation failed for an operation-specific reason"
+        //  message
+        self.datachannel()?.send_with_str(&format!("x{}", message))
+    }
+
+    /// Same as [NetworkManager::send_message], but allows to send byte array
+    pub fn send_u8_array(&self, message: &[u8]) -> Result<(), JsValue> {
+        self.datachannel()?.send_with_u8_array(message)
     }
 }
